@@ -105,6 +105,12 @@ class Command(BaseCommand):
     """
 
     option_list = BaseCommand.option_list + (
+            make_option(
+                '--type',
+                dest='type',
+                default='photos',
+                help='Type: photos|videos'
+            ),
             make_option(
                 '--debug',
                 dest='debug',
@@ -156,6 +162,10 @@ class Command(BaseCommand):
         # Handle connection with the backend
         client, bucket = get_contents(srcdir, debug)
 
+        print "-"*80
+        print "[***] Importing..."
+        print ""
+
         for file in bucket:
             #import pdb; pdb.set_trace()
             try:
@@ -166,15 +176,22 @@ class Command(BaseCommand):
             try:
                 im = mymodels.Photo.objects.get(origen=os.path.basename(filepath))
                 repetidas += 1
-                print "[***] Repetida: %s" % os.path.basename(filepath)
+                print "%04d - Repetida: %s" % (repetidas, os.path.basename(filepath))
             except:
-                print "[***] La imagen %s No esta en bd, descargar y agregar a bbdd y hacer thumb" % os.path.basename(filepath)
+                print "%04d - La imagen %s No esta en bd, descargar y agregar a bbdd y hacer thumb" % (total, os.path.basename(filepath))
                 #import pdb; pdb.set_trace()
                 nombre_imagen = "%s%s" % (slugify(str(os.path.splitext(os.path.basename(filepath))[0]).replace('/', '').replace(' ','_').replace(':','-')),
                                         str(os.path.splitext(os.path.basename(filepath))[1]))
 
-                # Descargar original a img
+                # Descargar original a img (si ya existe _1.jpg)
+                if os.path.exists(destdir + '/' + nombre_imagen) == True:
+                    nombre_imagen = "%s_1%s" % (slugify(str(os.path.splitext(os.path.basename(filepath))[0]).replace('/', '').replace(' ','_').replace(':','-')),
+                                                     str(os.path.splitext(os.path.basename(filepath))[1]))
+                    print "      Duplicada en disco, cambiado nombre a: %s" % nombre_imagen
+                    descargadas += 1
                 img = download(client, file, nombre_imagen, srcdir, destdir, debug)
+                print "      Guardada: %s/%s" % (destdir, nombre_imagen)
+
 
                 # Datos EXIF
                 data_image = get_exif(img)
@@ -187,46 +204,24 @@ class Command(BaseCommand):
                                     capture_date=capture_data,
                                     status=True)
                 im.save()
-                print im.origen
-                descargadas += 1
-                print "      Agregada a bbdd"
+                print "      Agregada a bbdd (%s)" % im.origen
 
                 # Abrimos imagen para modificaciones
                 im2 = Image.open(img) # Abrir
                 im2 = img_rotate(im2) # Rotar
-
-                # La guardamos después de rotada
-                if os.path.exists(destdir + '/' + nombre_imagen) == False:
-                    im2.save(destdir + '/' + nombre_imagen)
-                    print "      Guardada: %s/%s" % (destdir, nombre_imagen)
-                else:
-                    descargadas += 1
-                    nombre_imagen_repe = "%s_1%s" % (slugify(str(os.path.splitext(os.path.basename(filepath))[0]).replace('/', '').replace(' ','_').replace(':','-')),
-                                                     str(os.path.splitext(os.path.basename(filepath))[1]))
-                    im.image = "uploads/photos/" + nombre_imagen_repe
-                    im.save()
-                    im2.save(destdir + '/' + nombre_imagen_repe)
-                    print "      Duplicada en disco, cambiado nombre a: %s" % nombre_imagen_repe
-
-                # Creamos thumbs
-                for thumb in thumbs:
-                    print "      Thumb %sx%s" % (thumb, thumb)
-                    im = get_thumbnail(im, "%sx%s" % (thumb, thumb))
+                im2.save(destdir + '/' + nombre_imagen)
 
             total += 1
 
         print ""
-        print "[*** Resumen ***]"
+        print "-"*80
         print ""
-        print "[***] Repetidas en db: %s" % repetidas
-        print "[***] Repetidas en disco: %s" % descargadas
-        print "[***] Total: %s" % total
-
         print "[***] Making missing thumbs"
+        print ""
         conf.THUMBNAIL_DEBUG = True
         allphotos = mymodels.Photo.objects.all()
         for i,p in enumerate(allphotos):
-            print "%s - %s" % (i, p)
+            print "%04d - %s" % (i, p)
             c = Context({'image': p})
             t = Template('{% load thumbnail %}{% thumbnail image "200x200" crop="top" as img %}{{ img.url }}{% endthumbnail %}')
             t.render(c)
@@ -234,5 +229,13 @@ class Command(BaseCommand):
             for thumb in thumbs:
                 im = get_thumbnail(p, "%sx%s" % (thumb, thumb))
 
-        print "[***] Done."
-
+        print ""
+        print "-"*80
+        print ""
+        print "[***] Resumen"
+        print ""
+        print "[***] Repetidas en db: %s" % repetidas
+        print "[***] Repetidas en disco: %s" % descargadas
+        print "[***] Total: %s" % total
+        print ""
+        print "-"*80
